@@ -9,10 +9,6 @@ INFINITY_API_BASE_URL = "https://www.app-api.ing.carrier.com"
 INFINITY_API_CONSUMER_KEY = "8j30j19aj103911h"
 INFINITY_API_CONSUMER_SECRET = "0f5ur7d89sjv8d45"
 
-MODE_HEAT = "HEAT"
-MODE_COOL = "COOL"
-MODE_OFF = "OFF"
-
 
 class SystemModes(Enum):
     OFF = 'off'
